Template Tags
=============

***********
Simple Tags
***********

.. automodule:: tom_common.templatetags.tom_common_extras
   :members: comments_enabled, verbose_name

**************
Inclusion Tags
**************

.. automodule:: tom_common.templatetags.tom_common_extras
   :members: recent_comments
   :noindex:

*******
Filters
*******

.. automodule:: tom_common.templatetags.tom_common_extras
   :members: truncate_number
   :noindex: